@@ -3,6 +3,16 @@ from PyObjCTools.TestSupport import *
 from CoreText import *
 from Quartz import *
 
+try:
+    unicode
+except NameError:
+    unicode = str
+
+try:
+    long
+except NameError:
+    long = int
+
 class TestCTFont (TestCase):
     def testTypes(self):
         self.assertIsInstance(CTFontRef, objc.objc_class)
@@ -13,6 +23,20 @@ class TestCTFont (TestCase):
         self.assertEqual(kCTFontOptionsPreventAutoActivation, 1 << 0)
         self.assertEqual(kCTFontOptionsPreferSystemFont, 1 << 2)
 
+    @min_os_level('10.8')
+    def testConstants10_8(self):
+        self.assertIsInstance(kCTBaselineClassHanging, unicode)
+        self.assertIsInstance(kCTBaselineClassIdeographicCentered, unicode)
+        self.assertIsInstance(kCTBaselineClassIdeographicHigh, unicode)
+        self.assertIsInstance(kCTBaselineClassIdeographicLow, unicode)
+        self.assertIsInstance(kCTBaselineClassMath, unicode)
+        self.assertIsInstance(kCTBaselineClassRoman, unicode)
+        self.assertIsInstance(kCTBaselineOriginalFont, unicode)
+        self.assertIsInstance(kCTBaselineReferenceFont, unicode)
+        self.assertIsInstance(kCTBaselineReferenceFont, unicode)
+
+        self.assertEqual(kCTFontTableAnkr, fourcc(b'ankr'))
+
 
     def testConstants(self):
         self.assertIsInstance(kCTFontCopyrightNameKey, unicode)
@@ -34,7 +58,7 @@ class TestCTFont (TestCase):
         self.assertIsInstance(kCTFontSampleTextNameKey, unicode)
         self.assertIsInstance(kCTFontPostScriptCIDNameKey, unicode)
 
-        self.assertEqual(kCTFontNoFontType,  -1)
+        self.assertEqual(kCTFontNoFontType,  4294967295) # (uint32_t)-1
         self.assertEqual(kCTFontUserFontType,  0)
         self.assertEqual(kCTFontUserFixedPitchFontType,  1)
         self.assertEqual(kCTFontSystemFontType,  2)
@@ -137,7 +161,7 @@ class TestCTFont (TestCase):
         self.assertEqual(kCTFontTableOptionExcludeSynthetic, (1 << 0))
 
     def testFunctions(self):
-        font = CTFontCreateWithName(u"Optima Bold",
+        font = CTFontCreateWithName(b"Optima Bold".decode('latin1'),
                 14,
                 None)
         self.assertIsInstance(font, CTFontRef)
@@ -180,7 +204,7 @@ class TestCTFont (TestCase):
         self.assertResultIsCFRetained(CTFontCreateCopyWithFamily)
 
         font2 = CTFontCreateForString(
-                font, u"hello world", CFRange(1, 4))
+                font, b"hello world".decode('latin1'), CFRange(1, 4))
         self.assertIsInstance(font2, CTFontRef)
         self.assertResultIsCFRetained(CTFontCreateForString)
 
@@ -234,7 +258,7 @@ class TestCTFont (TestCase):
 
         self.assertArgIsOut(CTFontGetGlyphsForCharacters, 2)
         v, gl = CTFontGetGlyphsForCharacters(font,
-                u"hello", None, 5)
+                b"hello".decode('latin1'), None, 5)
 
         self.assertTrue(v is True)
         self.assertIsInstance(gl, tuple)
@@ -357,12 +381,12 @@ class TestCTFont (TestCase):
     @min_os_level('10.6')
     def testFunctions10_6(self):
         self.assertResultIsCFRetained(CTFontCreateWithNameAndOptions)
-        v = CTFontCreateWithNameAndOptions(u"Times", 15, None, 0)
+        v = CTFontCreateWithNameAndOptions(b"Times".decode('latin1'), 15, None, 0)
         self.assertIsInstance(v, CTFontRef)
 
 
         descr = CTFontDescriptorCreateWithNameAndSize(
-                u"Courier", 14.0)
+                b"Courier".decode('latin1'), 14.0)
         self.assertNotEqual(descr, None)
 
         # FIXME: this crashes the interpreter, without a clear reason
@@ -372,6 +396,15 @@ class TestCTFont (TestCase):
         v = CTFontCreateWithFontDescriptorAndOptions(descr, 14.0, None, 0)
         self.assertIsInstance(v, CTFontRef)
 
+    @expectedFailure
+    @min_os_level('10.7')
+    def testFunctions10_7(self):
+        self.fail("CTFontDrawGlyphs")
+
+    @expectedFailure
+    @min_os_level('10.8')
+    def testFunctions10_8(self):
+        self.fail("CTFontGetOpticalBoundsForGlyps")
 
 if __name__ == "__main__":
     main()
