@@ -2,6 +2,16 @@
 from PyObjCTools.TestSupport import *
 from CoreText import *
 
+try:
+    unicode
+except NameError:
+    unicode = str
+
+try:
+    long
+except NameError:
+    long = int
+
 class TestCTGlyphInfo (TestCase):
     def testTypes(self):
         self.assertIsInstance(CTGlyphInfoRef, objc.objc_class)
@@ -19,14 +29,14 @@ class TestCTGlyphInfo (TestCase):
         v = CTGlyphInfoGetTypeID()
         self.assertIsInstance(v, (int, long))
 
-        font = CTFontCreateWithName(u"Optima Bold", 14, None)
+        font = CTFontCreateWithName(b"Optima Bold".decode('latin1'), 14, None)
         self.assertIsInstance(font, CTFontRef)
 
         self.assertResultIsCFRetained(CTGlyphInfoCreateWithGlyphName)
         info = v = CTGlyphInfoCreateWithGlyphName(
-                u"copyright",
+                b"copyright".decode('latin1'),
                 font,
-                u"(c)")
+                b"(c)".decode('latin1'))
         self.assertIsInstance(v, CTGlyphInfoRef)
 
         self.assertResultIsCFRetained(CTGlyphInfoCreateWithGlyph)
@@ -34,7 +44,13 @@ class TestCTGlyphInfo (TestCase):
         self.assertIsInstance(v, CTGlyphInfoRef)
 
         self.assertResultIsCFRetained(CTGlyphInfoCreateWithCharacterIdentifier)
-        v = CTGlyphInfoCreateWithCharacterIdentifier(3254, kCTIdentityMappingCharacterCollection, "(c)")
+
+        for collection in (kCTIdentityMappingCharacterCollection, kCTAdobeCNS1CharacterCollection,
+                kCTAdobeGB1CharacterCollection, kCTAdobeJapan1CharacterCollection, 
+                kCTAdobeJapan2CharacterCollection, kCTAdobeKorea1CharacterCollection):
+            v = CTGlyphInfoCreateWithCharacterIdentifier(3254, collection, "(c)")
+            if v is not None:
+                break
         self.assertIsInstance(v, CTGlyphInfoRef)
 
         v = CTGlyphInfoGetGlyphName(info)
