@@ -2,6 +2,11 @@
 from PyObjCTools.TestSupport import *
 from CoreText import *
 
+try:
+    unicode
+except NameError:
+    unicode = str
+
 class TestCTStringAttributes (TestCase):
     def testConstants(self):
         self.assertIsInstance(kCTFontAttributeName, unicode)
@@ -26,14 +31,21 @@ class TestCTStringAttributes (TestCase):
     def testConstants10_5(self):
         self.assertIsInstance(kCTForegroundColorFromContextAttributeName, unicode)
         self.assertIsInstance(kCTSuperscriptAttributeName, unicode)
-        self.assertIsInstance(kCTUnderlineColorAttributeName, unicode)
         self.assertIsInstance(kCTCharacterShapeAttributeName, unicode)
 
     @min_os_level('10.6')
     def testConstants10_6(self):
+        self.assertIsInstance(kCTUnderlineColorAttributeName, unicode)
         self.assertIsInstance(kCTStrokeWidthAttributeName, unicode)
         self.assertIsInstance(kCTStrokeColorAttributeName, unicode)
 
+    @min_os_level('10.8')
+    def testConstants10_8(self):
+        self.assertIsInstance(kCTBaselineClassAttributeName, unicode)
+        self.assertIsInstance(kCTBaselineInfoAttributeName, unicode)
+        self.assertIsInstance(kCTBaselineReferenceInfoAttributeName, unicode)
+        self.assertIsInstance(kCTWritingDirectionAttributeName, unicode)
+
 
 if __name__ == "__main__":
     main()
