@@ -2,6 +2,16 @@
 from PyObjCTools.TestSupport import *
 from CoreText import *
 
+try:
+    unicode
+except NameError:
+    unicode = str
+
+try:
+    long
+except NameError:
+    long = int
+
 class TestCTTextTab (TestCase):
     def testTypes(self):
         self.assertIsCFType(CTTextTabRef)
@@ -12,7 +22,9 @@ class TestCTTextTab (TestCase):
     def testFunctions(self):
         self.assertIsInstance(CTTextTabGetTypeID(), (int, long))
 
-        tab = CTTextTabCreate(kCTCenterTextAlignment, 10.5, { u"key": u"value" })
+        tab = CTTextTabCreate(kCTCenterTextAlignment, 10.5, { 
+            kCTTabColumnTerminatorsAttributeName: CFCharacterSetCreateWithCharactersInString(None, b".".decode('latin1'))
+        })
         self.assertIsInstance(tab, CTTextTabRef)
 
         v = CTTextTabGetAlignment(tab)
